@@ -10,11 +10,15 @@ this_dir = pathlib.Path(__file__).resolve().parent
 def test_pacman():
     mesh = meshplex.read(this_dir / ".." / "meshes" / "pacman.vtk")
 
+    # mesh = meshplex.MeshTri(mesh.points[:, :2], mesh.cells["points"])
+    # mesh.signed_cell_volumes
+    # exit(1)
+
     # Create circular vector field 0.5 * (y, -x, 0)
     # which has curl (0, 0, 1).
     A = np.array([[-0.5 * coord[1], 0.5 * coord[0], 0.0] for coord in mesh.points])
     # Compute the curl numerically.
-    B = mesh.compute_curl(A)
+    B = mesh.compute_ncurl(A)
 
     # mesh.write(
     #     'curl.vtu',
