@@ -13,7 +13,7 @@ def test_signed_area_basic():
     cells = np.array([[0, 1, 2], [0, 3, 2]])
     mesh = meshplex.MeshTri(points, cells)
     ref = np.array([0.5, -0.55])
-    assert np.all(np.abs(mesh.signed_cell_areas - ref) < 1.0e-10 * np.abs(ref))
+    assert np.all(np.abs(mesh.signed_cell_volumes - ref) < 1.0e-10 * np.abs(ref))
 
 
 def test_signed_area_pacman():
@@ -23,9 +23,9 @@ def test_signed_area_pacman():
 
     mesh = meshplex.MeshTri(X, mesh.get_cells_type("triangle"))
 
-    vols = mesh.signed_cell_areas
+    vols = mesh.signed_cell_volumes
     # all cells are positively oriented in this mesh
-    assert np.all(mesh.signed_cell_areas > 0.0)
+    assert np.all(mesh.signed_cell_volumes > 0.0)
     assert np.all(abs(abs(vols) - mesh.cell_volumes) < 1.0e-12 * mesh.cell_volumes)
 
 
@@ -34,8 +34,8 @@ def test_signed_area2():
     cells = np.array([[0, 1, 2]])
     mesh = meshplex.MeshTri(points, cells)
     ref = 0.5
-    assert abs(mesh.signed_cell_areas[0] - ref) < 1.0e-10 * abs(ref)
+    assert abs(mesh.signed_cell_volumes[0] - ref) < 1.0e-10 * abs(ref)
 
     mesh.points = np.array([[0.0, 0.0], [0.0, 1.0], [1.0, 0.0]])
     ref = -0.5
-    assert abs(mesh.signed_cell_areas[0] - ref) < 1.0e-10 * abs(ref)
+    assert abs(mesh.signed_cell_volumes[0] - ref) < 1.0e-10 * abs(ref)
